==> jupyros-0.6.0a0.tar.gz: jupyros-0.6.0a0/CHANGELOG.md <==
# Changelog

<!-- <START NEW CHANGELOG ENTRY> -->

## 0.6.0a0

([Full Changelog](https://github.com/RoboStack/jupyter-ros/compare/0.5.0...1f6c46c9d24768a30817996445140d8ce956106d))

### Enhancements made

- Ros2 scalable [#119](https://github.com/RoboStack/jupyter-ros/pull/119) ([@ldania](https://github.com/ldania))
- Rename `client` to `service_client` [#117](https://github.com/RoboStack/jupyter-ros/pull/117) ([@ihuicatl](https://github.com/ihuicatl))
- Import ROS1 or ROS2 modules based on environment [#116](https://github.com/RoboStack/jupyter-ros/pull/116) ([@ihuicatl](https://github.com/ihuicatl))
- Adopt jupyter-releaser [#114](https://github.com/RoboStack/jupyter-ros/pull/114) ([@ihuicatl](https://github.com/ihuicatl))

### Bugs fixed

- Removes prints for ros env [#121](https://github.com/RoboStack/jupyter-ros/pull/121) ([@hbcarlos](https://github.com/hbcarlos))

### Maintenance and upkeep improvements

- Added build workflow [#118](https://github.com/RoboStack/jupyter-ros/pull/118) ([@hbcarlos](https://github.com/hbcarlos))

### Documentation improvements

- Rename `client` to `service_client` [#117](https://github.com/RoboStack/jupyter-ros/pull/117) ([@ihuicatl](https://github.com/ihuicatl))
- Organize and update notebooks [#115](https://github.com/RoboStack/jupyter-ros/pull/115) ([@ihuicatl](https://github.com/ihuicatl))
- Update to nodejs=14 to build docs [#112](https://github.com/RoboStack/jupyter-ros/pull/112) ([@ihuicatl](https://github.com/ihuicatl))
- Update requirements to build docs [#111](https://github.com/RoboStack/jupyter-ros/pull/111) ([@ihuicatl](https://github.com/ihuicatl))

### Other merged PRs

- Fixes For Ros2 Publisher [#120](https://github.com/RoboStack/jupyter-ros/pull/120) ([@ldania](https://github.com/ldania))
- Update documentation for Read the Docs [#110](https://github.com/RoboStack/jupyter-ros/pull/110) ([@ihuicatl](https://github.com/ihuicatl))
- Add contributing guidelines [#109](https://github.com/RoboStack/jupyter-ros/pull/109) ([@ihuicatl](https://github.com/ihuicatl))
- Prepare repository for ROS2 [#108](https://github.com/RoboStack/jupyter-ros/pull/108) ([@hbcarlos](https://github.com/hbcarlos))
- Make actionlib dependency optional [#107](https://github.com/RoboStack/jupyter-ros/pull/107) ([@ihuicatl](https://github.com/ihuicatl))
- Bump terser from 5.5.1 to 5.14.2 in /js [#106](https://github.com/RoboStack/jupyter-ros/pull/106) ([@dependabot](https://github.com/dependabot))
- Bump moment from 2.29.2 to 2.29.4 in /js [#105](https://github.com/RoboStack/jupyter-ros/pull/105) ([@dependabot](https://github.com/dependabot))
- Add widget and example for ROS actions [#104](https://github.com/RoboStack/jupyter-ros/pull/104) ([@ihuicatl](https://github.com/ihuicatl))
- Clear all notebook outputs [#103](https://github.com/RoboStack/jupyter-ros/pull/103) ([@ihuicatl](https://github.com/ihuicatl))
- Add ipycanvas dependency for Turtlesim animations [#102](https://github.com/RoboStack/jupyter-ros/pull/102) ([@ihuicatl](https://github.com/ihuicatl))
- Bump shell-quote from 1.7.2 to 1.7.3 in /js [#99](https://github.com/RoboStack/jupyter-ros/pull/99) ([@dependabot](https://github.com/dependabot))
- Optimize TurtleSim animation speed [#97](https://github.com/RoboStack/jupyter-ros/pull/97) ([@ihuicatl](https://github.com/ihuicatl))
- Bump node-fetch from 2.6.1 to 2.6.7 in /js [#96](https://github.com/RoboStack/jupyter-ros/pull/96) ([@dependabot](https://github.com/dependabot))
- Bump ansi-regex from 5.0.0 to 5.0.1 in /js [#95](https://github.com/RoboStack/jupyter-ros/pull/95) ([@dependabot](https://github.com/dependabot))
- Add Turtlesim Widget [#94](https://github.com/RoboStack/jupyter-ros/pull/94) ([@ihuicatl](https://github.com/ihuicatl))
- Bump moment from 2.24.0 to 2.29.2 in /js [#93](https://github.com/RoboStack/jupyter-ros/pull/93) ([@dependabot](https://github.com/dependabot))
- Add ROS service/client widget [#92](https://github.com/RoboStack/jupyter-ros/pull/92) ([@ihuicatl](https://github.com/ihuicatl))
- Bump minimist from 1.2.5 to 1.2.6 in /js [#91](https://github.com/RoboStack/jupyter-ros/pull/91) ([@dependabot](https://github.com/dependabot))
- Bump nanoid from 3.1.23 to 3.2.0 in /js [#90](https://github.com/RoboStack/jupyter-ros/pull/90) ([@dependabot](https://github.com/dependabot))
- Bump tar from 6.1.0 to 6.1.11 in /js [#87](https://github.com/RoboStack/jupyter-ros/pull/87) ([@dependabot](https://github.com/dependabot))
- Bump path-parse from 1.0.6 to 1.0.7 in /js [#86](https://github.com/RoboStack/jupyter-ros/pull/86) ([@dependabot](https://github.com/dependabot))
- Bump socket.io-parser from 3.3.0 to 3.3.2 in /js [#84](https://github.com/RoboStack/jupyter-ros/pull/84) ([@dependabot](https://github.com/dependabot))
- Readme: Use conda to install [#83](https://github.com/RoboStack/jupyter-ros/pull/83) ([@Tobias-Fischer](https://github.com/Tobias-Fischer))
- Bump postcss from 8.2.4 to 8.3.4 in /js [#82](https://github.com/RoboStack/jupyter-ros/pull/82) ([@dependabot](https://github.com/dependabot))
- Bump glob-parent from 5.1.1 to 5.1.2 in /js [#81](https://github.com/RoboStack/jupyter-ros/pull/81) ([@dependabot](https://github.com/dependabot))
- Bump normalize-url from 4.5.0 to 4.5.1 in /js [#80](https://github.com/RoboStack/jupyter-ros/pull/80) ([@dependabot](https://github.com/dependabot))
- Bump browserslist from 4.16.1 to 4.16.6 in /js [#79](https://github.com/RoboStack/jupyter-ros/pull/79) ([@dependabot](https://github.com/dependabot))
- Bump lodash from 4.17.20 to 4.17.21 in /js [#77](https://github.com/RoboStack/jupyter-ros/pull/77) ([@dependabot](https://github.com/dependabot))
- Bump hosted-git-info from 2.7.1 to 2.8.9 in /js [#76](https://github.com/RoboStack/jupyter-ros/pull/76) ([@dependabot](https://github.com/dependabot))
- Bump underscore from 1.9.1 to 1.13.1 in /js [#75](https://github.com/RoboStack/jupyter-ros/pull/75) ([@dependabot](https://github.com/dependabot))
- Restore classic notebook & voila [#74](https://github.com/RoboStack/jupyter-ros/pull/74) ([@wolfv](https://github.com/wolfv))

### Contributors to this release

([GitHub contributors page for this release](https://github.com/RoboStack/jupyter-ros/graphs/contributors?from=2021-04-20&to=2022-08-11&type=c))

[@dependabot](https://github.com/search?q=repo%3ARoboStack%2Fjupyter-ros+involves%3Adependabot+updated%3A2021-04-20..2022-08-11&type=Issues) | [@hbcarlos](https://github.com/search?q=repo%3ARoboStack%2Fjupyter-ros+involves%3Ahbcarlos+updated%3A2021-04-20..2022-08-11&type=Issues) | [@ihuicatl](https://github.com/search?q=repo%3ARoboStack%2Fjupyter-ros+involves%3Aihuicatl+updated%3A2021-04-20..2022-08-11&type=Issues) | [@ldania](https://github.com/search?q=repo%3ARoboStack%2Fjupyter-ros+involves%3Aldania+updated%3A2021-04-20..2022-08-11&type=Issues) | [@Tobias-Fischer](https://github.com/search?q=repo%3ARoboStack%2Fjupyter-ros+involves%3ATobias-Fischer+updated%3A2021-04-20..2022-08-11&type=Issues) | [@wolfv](https://github.com/search?q=repo%3ARoboStack%2Fjupyter-ros+involves%3Awolfv+updated%3A2021-04-20..2022-08-11&type=Issues)

<!-- <END NEW CHANGELOG ENTRY> -->

## 0.5.0

==> jupyros-0.6.1.tar.gz: jupyros-0.6.1/CHANGELOG.md <==
# Changelog

<!-- <START NEW CHANGELOG ENTRY> -->

## 0.6.0

([Full Changelog](https://github.com/RoboStack/jupyter-ros/compare/v0.6.0a0...8d7849492ab7da88e6831e5e78cdae7ae9a0a8e0))

### Bugs fixed

- Fix error when building the extension [#127](https://github.com/RoboStack/jupyter-ros/pull/127) ([@ihuicatl](https://github.com/ihuicatl))

### Contributors to this release

([GitHub contributors page for this release](https://github.com/RoboStack/jupyter-ros/graphs/contributors?from=2022-08-11&to=2022-09-14&type=c))

[@hbcarlos](https://github.com/search?q=repo%3ARoboStack%2Fjupyter-ros+involves%3Ahbcarlos+updated%3A2022-08-11..2022-09-14&type=Issues) | [@ihuicatl](https://github.com/search?q=repo%3ARoboStack%2Fjupyter-ros+involves%3Aihuicatl+updated%3A2022-08-11..2022-09-14&type=Issues)

<!-- <END NEW CHANGELOG ENTRY> -->

## 0.6.0a0

([Full Changelog](https://github.com/RoboStack/jupyter-ros/compare/0.5.0...1f6c46c9d24768a30817996445140d8ce956106d))

### Enhancements made

- Ros2 scalable [#119](https://github.com/RoboStack/jupyter-ros/pull/119) ([@ldania](https://github.com/ldania))
- Rename `client` to `service_client` [#117](https://github.com/RoboStack/jupyter-ros/pull/117) ([@ihuicatl](https://github.com/ihuicatl))
- Import ROS1 or ROS2 modules based on environment [#116](https://github.com/RoboStack/jupyter-ros/pull/116) ([@ihuicatl](https://github.com/ihuicatl))
- Adopt jupyter-releaser [#114](https://github.com/RoboStack/jupyter-ros/pull/114) ([@ihuicatl](https://github.com/ihuicatl))

### Bugs fixed

- Removes prints for ros env [#121](https://github.com/RoboStack/jupyter-ros/pull/121) ([@hbcarlos](https://github.com/hbcarlos))

### Maintenance and upkeep improvements

- Added build workflow [#118](https://github.com/RoboStack/jupyter-ros/pull/118) ([@hbcarlos](https://github.com/hbcarlos))

### Documentation improvements

- Rename `client` to `service_client` [#117](https://github.com/RoboStack/jupyter-ros/pull/117) ([@ihuicatl](https://github.com/ihuicatl))
- Organize and update notebooks [#115](https://github.com/RoboStack/jupyter-ros/pull/115) ([@ihuicatl](https://github.com/ihuicatl))
- Update to nodejs=14 to build docs [#112](https://github.com/RoboStack/jupyter-ros/pull/112) ([@ihuicatl](https://github.com/ihuicatl))
- Update requirements to build docs [#111](https://github.com/RoboStack/jupyter-ros/pull/111) ([@ihuicatl](https://github.com/ihuicatl))

### Other merged PRs

- Fixes For Ros2 Publisher [#120](https://github.com/RoboStack/jupyter-ros/pull/120) ([@ldania](https://github.com/ldania))
- Update documentation for Read the Docs [#110](https://github.com/RoboStack/jupyter-ros/pull/110) ([@ihuicatl](https://github.com/ihuicatl))
- Add contributing guidelines [#109](https://github.com/RoboStack/jupyter-ros/pull/109) ([@ihuicatl](https://github.com/ihuicatl))
- Prepare repository for ROS2 [#108](https://github.com/RoboStack/jupyter-ros/pull/108) ([@hbcarlos](https://github.com/hbcarlos))
- Make actionlib dependency optional [#107](https://github.com/RoboStack/jupyter-ros/pull/107) ([@ihuicatl](https://github.com/ihuicatl))
- Bump terser from 5.5.1 to 5.14.2 in /js [#106](https://github.com/RoboStack/jupyter-ros/pull/106) ([@dependabot](https://github.com/dependabot))
- Bump moment from 2.29.2 to 2.29.4 in /js [#105](https://github.com/RoboStack/jupyter-ros/pull/105) ([@dependabot](https://github.com/dependabot))
- Add widget and example for ROS actions [#104](https://github.com/RoboStack/jupyter-ros/pull/104) ([@ihuicatl](https://github.com/ihuicatl))
- Clear all notebook outputs [#103](https://github.com/RoboStack/jupyter-ros/pull/103) ([@ihuicatl](https://github.com/ihuicatl))
- Add ipycanvas dependency for Turtlesim animations [#102](https://github.com/RoboStack/jupyter-ros/pull/102) ([@ihuicatl](https://github.com/ihuicatl))
- Bump shell-quote from 1.7.2 to 1.7.3 in /js [#99](https://github.com/RoboStack/jupyter-ros/pull/99) ([@dependabot](https://github.com/dependabot))
- Optimize TurtleSim animation speed [#97](https://github.com/RoboStack/jupyter-ros/pull/97) ([@ihuicatl](https://github.com/ihuicatl))
- Bump node-fetch from 2.6.1 to 2.6.7 in /js [#96](https://github.com/RoboStack/jupyter-ros/pull/96) ([@dependabot](https://github.com/dependabot))
- Bump ansi-regex from 5.0.0 to 5.0.1 in /js [#95](https://github.com/RoboStack/jupyter-ros/pull/95) ([@dependabot](https://github.com/dependabot))
- Add Turtlesim Widget [#94](https://github.com/RoboStack/jupyter-ros/pull/94) ([@ihuicatl](https://github.com/ihuicatl))
- Bump moment from 2.24.0 to 2.29.2 in /js [#93](https://github.com/RoboStack/jupyter-ros/pull/93) ([@dependabot](https://github.com/dependabot))
- Add ROS service/client widget [#92](https://github.com/RoboStack/jupyter-ros/pull/92) ([@ihuicatl](https://github.com/ihuicatl))
- Bump minimist from 1.2.5 to 1.2.6 in /js [#91](https://github.com/RoboStack/jupyter-ros/pull/91) ([@dependabot](https://github.com/dependabot))
- Bump nanoid from 3.1.23 to 3.2.0 in /js [#90](https://github.com/RoboStack/jupyter-ros/pull/90) ([@dependabot](https://github.com/dependabot))
- Bump tar from 6.1.0 to 6.1.11 in /js [#87](https://github.com/RoboStack/jupyter-ros/pull/87) ([@dependabot](https://github.com/dependabot))
- Bump path-parse from 1.0.6 to 1.0.7 in /js [#86](https://github.com/RoboStack/jupyter-ros/pull/86) ([@dependabot](https://github.com/dependabot))
- Bump socket.io-parser from 3.3.0 to 3.3.2 in /js [#84](https://github.com/RoboStack/jupyter-ros/pull/84) ([@dependabot](https://github.com/dependabot))
- Readme: Use conda to install [#83](https://github.com/RoboStack/jupyter-ros/pull/83) ([@Tobias-Fischer](https://github.com/Tobias-Fischer))
- Bump postcss from 8.2.4 to 8.3.4 in /js [#82](https://github.com/RoboStack/jupyter-ros/pull/82) ([@dependabot](https://github.com/dependabot))
- Bump glob-parent from 5.1.1 to 5.1.2 in /js [#81](https://github.com/RoboStack/jupyter-ros/pull/81) ([@dependabot](https://github.com/dependabot))
- Bump normalize-url from 4.5.0 to 4.5.1 in /js [#80](https://github.com/RoboStack/jupyter-ros/pull/80) ([@dependabot](https://github.com/dependabot))
- Bump browserslist from 4.16.1 to 4.16.6 in /js [#79](https://github.com/RoboStack/jupyter-ros/pull/79) ([@dependabot](https://github.com/dependabot))
- Bump lodash from 4.17.20 to 4.17.21 in /js [#77](https://github.com/RoboStack/jupyter-ros/pull/77) ([@dependabot](https://github.com/dependabot))
- Bump hosted-git-info from 2.7.1 to 2.8.9 in /js [#76](https://github.com/RoboStack/jupyter-ros/pull/76) ([@dependabot](https://github.com/dependabot))
- Bump underscore from 1.9.1 to 1.13.1 in /js [#75](https://github.com/RoboStack/jupyter-ros/pull/75) ([@dependabot](https://github.com/dependabot))
- Restore classic notebook & voila [#74](https://github.com/RoboStack/jupyter-ros/pull/74) ([@wolfv](https://github.com/wolfv))

### Contributors to this release

([GitHub contributors page for this release](https://github.com/RoboStack/jupyter-ros/graphs/contributors?from=2021-04-20&to=2022-08-11&type=c))

[@dependabot](https://github.com/search?q=repo%3ARoboStack%2Fjupyter-ros+involves%3Adependabot+updated%3A2021-04-20..2022-08-11&type=Issues) | [@hbcarlos](https://github.com/search?q=repo%3ARoboStack%2Fjupyter-ros+involves%3Ahbcarlos+updated%3A2021-04-20..2022-08-11&type=Issues) | [@ihuicatl](https://github.com/search?q=repo%3ARoboStack%2Fjupyter-ros+involves%3Aihuicatl+updated%3A2021-04-20..2022-08-11&type=Issues) | [@ldania](https://github.com/search?q=repo%3ARoboStack%2Fjupyter-ros+involves%3Aldania+updated%3A2021-04-20..2022-08-11&type=Issues) | [@Tobias-Fischer](https://github.com/search?q=repo%3ARoboStack%2Fjupyter-ros+involves%3ATobias-Fischer+updated%3A2021-04-20..2022-08-11&type=Issues) | [@wolfv](https://github.com/search?q=repo%3ARoboStack%2Fjupyter-ros+involves%3Awolfv+updated%3A2021-04-20..2022-08-11&type=Issues)

## 0.5.0
